# test-report.html

Report generated on 14-Apr-2023 at 15:50:31 by pytest-html v3.2.0

## Environment

JAVA_HOME | /Users/tnguyen/Library/Java/JavaVirtualMachines/corretto-1.8.0_352/Contents/Home
Packages | {"pluggy": "1.0.0", "pytest": "7.3.0"}
Platform | macOS-13.3-x86_64-i386-64bit
Plugins | {"html": "3.2.0", "metadata": "2.0.4"}
Python | 3.9.6

## Summary

6 tests ran in 3.93 seconds.

(Un)check the boxes to filter the results.

6 passed, 0 skipped, 0 failed, 0 errors, 0 expected failures, 0 unexpected passes

## Results

Result | Test | Duration | Links
--- | --- | --- | ---
No results found. Try to check the filters
Passed | test/test_services.py::test_get_model_info | 0.64 |
No log output captured.
Passed | test/test_services.py::test_get_model_files_info | 0.45 |
No log output captured.
Passed | test/test_services.py::test_get_model_identifiers | 0.14 |
No log output captured.
Passed | test/test_services.py::test_download | 0.19 |
No log output captured.
Passed | test/test_services.py::test_search | 0.70 |
No log output captured.
Passed | test/test_services.py::test_parameter_search | 1.59 |
No log output captured.